######################################################################
#
%label="Lineage Analyzer (subdisplay)"
#
#%iconPath="C:\\Program Files\\MetaIntegration\\MIRWeb\\images"
#
######################################################################
#
# The Meta Integration Repository (MIR) stores metadata under the
# powerful MIR metamodel which is fairly large and complex as it
# implements and integrates many standard metamodels like the OMG UML
# and CWM, IDEF1X, W3C, as well as metamodels from tool vendors like
# IBM, Microsoft, Oracle, etc. The MIR metamodel vocabulary is
# therefore primarily driven by the OMG UML & CWM metamodels with
# notions of Classifier, Feature, ClassifierMap, FeatureMap.
# If not experienced with the OMG UML and CWM vocabulary,
# the Meta Integration tool users may not be knowledgeable of
# the MIR vocabulary when browsing models in Meta Integration Works
# (MIW) or in MIR Web. However, users can define views on the
# MIR Metamodel known as "Profiles" in order to: 
#	- filter out metadata they are not interested to see, 
#	- rename metadata to their own terminology
#		(e.g. Classifier, Class, Entity, Table), 
#	- associate metadata with the icons of their usual tools, 
#	- filter out or rename properties (attributes). 
#
# Meta Integration Repository (MIR) Profiles corresponds to the concepts
# of OMG UML Profiles. Note that the MIR Profiles are not only used by
# the Model Browser, but also the Model Comparator in order to generate
# custom comparison filters. 
# When using the Model Browser of MIW or MIR Web, a default (mandatory)
# view called "Meta Integration (UML, CWM, IDEF1X)" shows all available
# metadata in the MIR repository. Other customizable profiles are
# available in the Meta Integration install directory, for example: 
#	C:\Program Files\MetaIntegration\Profiles\*.profile
# These files can be customized to produce business vs. technical views,
# or tool oriented views like ERwin, Informatica, BO. You can start
# from the most appropriate profile templates: MyMIR.profile,
# MyIDEF1X.profile, MyRDBMS.profile, MyUML.profile or MyXML.profile 
# The profile file is organized by order of inheritance since some
# child object views can override some properties of their parent.
#
# The overall syntax is defined as follows: 
# 
#	# Comments
#	
#	%label="ProfileName"
#	[%iconPath="C:\\Program Files\\MetaIntegration\\MIRWeb\\images"]
#	
#	MetaClassName[="NewMetaClassName"] {
#	Attributes
#		[!][-]MetaAttributeName[="NewMetaAttributeName"];
#	Links
#		[!][-|+]MetaLinkName[="NewMetaLinkName"];
#	Icons
#		icon="Icons/ProfileName/MetaClassName.gif";
#	}
#
# Here are a few customization tips on the syntax of .profile files: 
#
# - Naming a profile: 
#	%label="MyViewNameHere"
#
# - Renaming classes, attributes, or links using "=" 
#	CppPersistent="Persistent"
#
# - Removing (native or inherited) attributes or links using "!" 
#	!CppAbstract;
#
# - Removing (native or inherited) classes by removing the agregation link from the parent class, for example: 
#	Package {
#	Links
#		!Diagram;
#	}
#
# - Updating the icon using "icon=" 
#	icon="icons/MIR/Operation.gif";
#
# - new icon file names must be: 
#	MetaClassName.gif
#
# - new icons for MIW are by default located in: 
#	C:\Program Files\MetaIntegration\Profiles\
#
# - new icons for MIW can be located in a new location (e.g. shared with MIRWeb) defined using "iconPath"
#		(Note that the path should include \\ or / , but not just \): 
#	%iconPath="C:\\Program Files\\MetaIntegration\\MIRWeb\\images"
#
# - new icons for MIRWeb are by default located in: 
#	C:\Program Files\MetaIntegration\MIRWeb\images
#
# - the path for Profiles and Icons in MIRWeb can be customized in MIRWeb.ini as follows: 
#	ProfilePath=C:\Program Files\MetaIntegration\Profiles
#	ProfileIconRelativePath=images
#
# - Changing Attributes (by default editable) to be no longer Editable using "-" 
#	-CppAbstract;
#
# - Changing Links (by default navigable) to be no longer Navigable using "-" 
#	or to be navigable again using "+" (in case of inherited no longer navigable links) 
#	-Diagram;
#
######################################################################

Object {
Attributes
	-ElementType="Element Type";
	-Name;
	-ID;
Links
Icons
	icon="icons/MIR/Object.gif";
}

Note {
Attributes
    Value;
    Position;
Links
    !Element;
Icons
	icon="icons/MIR/Note.gif";
}

Element {
Attributes
	Description;
Links
	Note;
	PropertyValue;
	!<back>ElementNode;
	!<back>ElementNamePart.ReferencedBy;
Icons
	icon="icons/MIR/Element.gif";
}

MetadataOrigin {
Attributes
	VendorName="Vendor Name";
	ToolName="Tool Name";
	ToolVersion="Tool Version";
	FormatName="Format Name";
	FormatVersion="Format Version";
	BridgeName="Bridge Name";
	BridgeVersion="Bridge Version";
	Encoding;
    Source;
    ResourceType="Resource Type";
Links
	!Model;
	!MappingModel;
Icons
	icon="icons/MIR/MetadataOrigin.gif";
}

TypeValue {
Attributes
	Position;
	Value;
Links
	!DerivedType;
	!BusinessRule;
	!<external|forward>TypeValueMap.DestinationOf;
	!<external|back>TypeValueMap.SourceOf;
Icons
	icon="icons/MIR/TypeValue.gif";
}

PropertyElementTypeScope {
Attributes
	Scope;
Links
	!Model;
	!MappingModel;
	PropertyType;
Icons
	icon="icons/MIR/PropertyElementTypeScope.gif";
}

PropertyValue {
Attributes
	Value;
	Position;
Links
	!Element;
	PropertyType;
Icons
	icon="icons/MIR/PropertyValue.gif";
}

########################################################
# Repository metadata (Inherits from RepositoryObject) #
########################################################

RepositoryObject {
Attributes
	-CreationTime="Creation Time";
Links
    !PropertyValue;
Icons
	icon="icons/MIR/RepositoryObject.gif";
}

Directory {
Attributes
Links
	Product;
Icons
	icon="icons/MIR/Directory.gif";
}

Component {
Attributes
Links
	Component.Referenced;
	Component.ReferencedBy;
Icons
	icon="icons/MIR/Component.gif";
}

Product {
Attributes
	Description;
	ProductType="Product Type";
	Author;
	State;
Links
	!Directory;
	!Product.Parent;
	Product.Child;
	Version;
	<check>Version.Default;
Icons
	icon="icons/MIR/Product.gif";
}

Version {
Attributes
	Description;
Links
	!Product;
	!Product.DefaultOf;
	<original>Format.Original;
	<check>Format.Default;
	Format;
	<double|back>Version.Predecessor;
	<double|forward>Version.Successor;
Icons
	icon="icons/MIR/Version.gif";
}

Format {
Attributes
	FormatType="Format Type";
	Author;
Links
	!Version;
	!Version.OriginalOf;
	!Version.DefaultOf;
Icons
	icon="icons/MIR/Format.gif";
}

FileFormat {
Attributes
	-Location;
Links
Icons
	icon="icons/MIR/FileFormat.gif";
}

MetadataFormat {
Attributes
Links
Icons
	icon="icons/MIR/MetadataFormat.gif";
}

ModelFormat {
Attributes
Links
	!Model;
	<back>MappingFormat.SourceOf;
	<forward>MappingFormat.DestinationOf;
Icons
	icon="icons/MIR/ModelFormat.gif";
}

MappingFormat {
Attributes
Links
	!MappingModel;
	<back>ModelFormat.Source;
	<forward>ModelFormat.Destination;
Icons
	icon="icons/MIR/MappingFormat.gif";
}

DataMovementFormat {
Attributes
Links
Icons
	icon="icons/MIR/DataMovementFormat.gif";
}

##############################################
# Model metadata (inherits from ModelObject) #
##############################################

ModelObject {
Attributes
	PhysicalID="Physical ID";
	PhysicalName="Physical Name";
	Status;
	Comment;
	DesignLevel="Design Level";
	Stereotype;
Links
	Synonym;
	<external|back>KeyMap.SourceOf;
	PhysicalObject.Associated;
	BusinessRule.Associated;
	PresentationElement.Presentation=;
	DataPackage;
	DesignPackage.ImportedBy;
Icons
	icon="icons/MIR/ModelObject.gif";
}

Synonym {
Attributes
Links
    !ModelObject;
Icons
	icon="icons/MIR/Synonym.gif";
}

BusinessRule {
Attributes
    Type;
    Value;
    LowerBound="Lower Bound";
    UpperBound="Upper Bound";
Links
    TypeValue;
    ModelObject;
    !Model;
Icons
	icon="icons/MIR/BusinessRule.gif";
}

ModelElement {
Attributes
Links
	!DesignPackage;
	Diagram;
Icons
	icon="icons/MIR/ModelElement.gif";
}

Type {
Attributes
Links
	!Model;
	!MappingModel;
	AliasType;
	Argument;
	Feature;
	Operation;
	ExpressionNode;
Icons
	icon="icons/MIR/Type.gif";
}

# AliasType displays the Type.AliasOf link first
AliasType {
Attributes
Links
	Type.AliasOf;
	Argument;
	Feature;
	Operation;
Icons
	icon="icons/MIR/AliasType.gif";
}

ClassType {
Attributes
Links
	<forward>Class.Associated=;
	AliasType;
	Argument;
	Feature;
	Operation;
Icons
	icon="icons/MIR/ClassType.gif";
}

ConcreteType {
Attributes
	DataType="Data Type";
	Length;
	Scale;
Links
	DerivedType;
Icons
	icon="icons/MIR/ConcreteType.gif";
}

BaseType {
Attributes
Links
Icons
	icon="icons/MIR/BaseType.gif";
}

DerivedType {
Attributes
	InitialValue="Initial Value";
	LowerBound="Lower Bound";
	UpperBound="Upper Bound";
	UserDefined="User Defined";
	NativeDataType="Native Data Type";
	UserDataType="User Data Type";
Links
	<back>ConcreteType.DerivedFrom;
	TypeValue;
	<external|forward>EnumeratedTypeMap.DestinationOf;
	<external|back>EnumeratedTypeMap.SourceOf;
	AliasType;
	Argument;
	Feature;
	Operation;
Icons
	icon="icons/MIR/DerivedType.gif";
}

PropertyType {
Attributes
	Usage;
	Group;
	Position;
Links
	!PropertyElementTypeScope;
	PropertyValue.Instanciated;
Icons
	icon="icons/MIR/PropertyType.gif";
}

Classifier {
Attributes
Links
	<external|forward>ClassifierMap.DestinationOf;
	<external|back>ClassifierMap.SourceOf;
	Feature;
	JoinRole.Associated;
	<back>SQLViewAssociation.SourceOf;
Icons
	icon="icons/MIR/Classifier.gif";
}

Feature {
Attributes
	Position;
Links
	!Classifier;
	<external|forward>FeatureMap.DestinationOf;
	<external|back>FeatureMap.SourceOf;
	Type;
	<back>SQLViewAttribute.SourceOf;
Icons
	icon="icons/MIR/Feature.gif";
}

StructuralFeature {
Attributes
	InitialValue="Initial Value";
	Optional;
Links
Icons
	icon="icons/MIR/StructuralFeature.gif";
}

Class {
Attributes
	CppClassType="Cpp Class Type";
	CppScope="Cpp Scope";
	CppConcurrency="Cpp Concurrency";
	CppAbstract="Cpp Abstract";
	CppPersistent="Cpp Persistent";
	CppMultiplicity="Cpp Multiplicity";
	CppSpace="Cpp Space";
	DimensionalType;
	DimensionalRole;
Links
	Argument;
	Association;
	<check>CandidateKey.Primary;
	Key;
	Index;
	Operation;
	Grouping;
	<up>Generalization.SubtypeOf;
	<down>Generalization.SupertypeOf;
	AssociationRole;
	<forward>Dependency;
	<back>Dependency.SupplierOf;
	<forward>Realization;
	<back>Realization.SpecificationOf;
	<back>ClassType;
	!MappingModel;
Icons
	icon="icons/MIR/Class.gif";
}

Attribute {
Attributes
	CppScope="Cpp Scope";
	CppContainment="Cpp Containement";
	CppStatic="Cpp Static";
	CppDerived="Cpp Derived";
	ExtraConstraint="Constraint";
Links
	!AssociationRole.QualifierOf;
	Key;
	IndexMember;
	<forward>AssociationRoleNameMap.DestinationOf;
	<back>AssociationRoleNameMap.SourceOf;
	Generalization.DiscriminatorOf;
	<external|forward>ClassMap.SourceOf;
	<external|forward>ClassMap.DestinationOf;
	Grouping;
Icons
	icon="icons/MIR/Attribute.gif";
}

ArtificialAttribute {
Attributes
Links
Icons
	icon="icons/MIR/ArtificialAttribute.gif";
}

SQLViewAssociation {
Attributes
	SQLTableSequence="SQL Table Sequence";
Links
	<back>Classifier.Source;
	<forward>SQLViewEntity.Destination;
Icons
	icon="icons/MIR/SQLViewAssociation.gif";
}

SQLViewAttribute {
Attributes
	Expression;
Links
	<back>Feature.Source;
Icons
	icon="icons/MIR/SQLViewAttribute.gif";
}

SQLViewEntity {
Attributes
	SQLTableWhereClause="SQL Table Where Clause";
Links
	Operation;
	<forward>SQLViewAssociation.DestinationOf;
Icons
	icon="icons/MIR/SQLViewEntity.gif";
}

AliasClassifier {
Attributes
Links
Icons
	icon="icons/MIR/AliasClassifier.gif";
}

AliasFeature {
Attributes
Links
Icons
	icon="icons/MIR/AliasFeature.gif";
}

Model {
Attributes
	-CreationTime="Creation Time";
Links
	!ModelFormat;
	MetadataOrigin;
	Type;
	BusinessRule;
	PropertyElementTypeScope;
	PhysicalTarget;
Icons
	icon="icons/MIR/Model.gif";
}

Package {
Attributes
Links
    !Package.Parent;
    Package.Child;
Icons
    icon="icons/MIR/Package.gif";
}

DesignPackage {
Attributes
	UserDefined="User Defined";
Links
	TransformationActivity;
	TransformationTask;
	Diagram.Default;
	Diagram;
	ModelElement;
	StoredProcedure;
	ModelObject.Imported;
Icons
	icon="icons/MIR/DesignPackage.gif";
}

DataPackage {
Attributes
    Direction;
Links
    ModelObject;
Icons
	icon="icons/MIR/DataPackage.gif";
}
 
DatabaseCatalog {
Attributes
    SystemType="System Type";
    NativeVersion="Native Version";
    MajorVersion="Major Version Number";
    MinorVersion="Minor Version Number";
    TertiaryVersion="Release Version Number";
Links
Icons
	icon="icons/MIR/DatabaseCatalog.gif";
}

DatabaseSchema {
Attributes
Links
Icons
	icon="icons/MIR/DatabaseSchema.gif";
}

Operation {
Attributes
	Position;
	CppScope="Cpp Scope";
	CppConcurrency="Cpp Concurrency";
	CppAbstract="Cpp Abstract";
	CppFriend="Cpp Friend";
	CppStatic="Cpp Static";
	CppVirtual="Cpp Virtual";
	Semantics;
	Precondition;
	Postcondition;
Links
	Type.Return;
	Argument;
	!Class.Associated;
	!SQLViewEntity.Associated;
	!<back>OperationNode;
Icons
	icon="icons/MIR/Operation.gif";
}

StoredProcedure {
Attributes
Links
	!DesignPackage;
Icons
	icon="icons/MIR/Operation.gif";
}

Trigger {
Attributes
	TriggerType="Trigger Type";
	FireOnInsert="Fire on Insert";
	FireOnUpdate="Fire on Updated";
	FireOnDelete="Fire on Delete";
Links
Icons
	icon="icons/MIR/Operation.gif";
}

Argument {
Attributes
	Position;
	DefaultValue="Default Value";
	Kind;
Links
	!Operation;
	!Class.Parameterized;
	Type;
Icons
	icon="icons/MIR/Argument.gif";
}

Relationship {
Attributes
Links
Icons
	icon="icons/MIR/Relationship.gif";
}

Realization {
Attributes
Links
	<back>Class.Specification;
	<forward>Class.Realization;
Icons
	icon="icons/MIR/Realization.gif";
}

Dependency {
Attributes
Links
	<forward>Class.Client;
	<back>Class.Supplier;
Icons
	icon="icons/MIR/Dependency.gif";
}

Generalization {
Attributes
	CppScope="Cpp Scope";
	CppVirtual="Cpp Virtual";
	CppFriend="Cpp Friend";
Links
	<up>Class.Supertype;
	<down>Class.Subtype;
	Attribute.Discriminator;
	ForeignKey;
Icons
	icon="icons/MIR/Generalization.gif";
}

Association {
Attributes
	Aggregation;
	ExtraConstraint="Constraint";
	UserDefined="User Defined";
Links
	Class.Associated=;
	AssociationRole;
Icons
	icon="icons/MIR/Association.gif";
}

AssociationRole {
Attributes
	Position;
	Source;
	Multiplicity;
	Navigable;
	Ordered;
	ExtraConstraint="Constraint";
	CppScope="Cpp Scope";
	CppContainment="Cpp Containement";
	CppStatic="Cpp Static";
	CppFriend="Cpp Friend";
Links
	!Association;
	Attribute.Qualifier;
	ForeignKey;
	Class.Associated=;
	Grouping;
Icons
	icon="icons/MIR/AssociationRole.gif";
}

AssociationRoleNameMap {
Attributes
Links
	!ForeignKey;
	<back>Attribute.Source;
	<forward>Attribute.Destination;
Icons
	icon="icons/MIR/AssociationRoleNameMap.gif";
}

Grouping {
Attributes
	Position;
	GroupingType="Grouping Type";
	Multiplicity;
Links
	!Class.Associated;
	!Grouping.Parent;
	Grouping.Child;
	AssociationRole.Leaf;
	Attribute.Leaf;
Icons
	icon="icons/MIR/Grouping.gif";
}

Key {
Attributes
Links
	!Class.Associated;
	Attribute;
	Index;
	<external|forward>KeyMap.DestinationOf;
Icons
	icon="icons/MIR/Key.gif";
}

ForeignKey {
Attributes
Links
	AssociationRole;
	Generalization;
	CandidateKey;
	AssociationRoleNameMap;
Icons
	icon="icons/MIR/ForeignKey.gif";
}

CandidateKey {
Attributes
	UniqueKey="Unique Key";
Links
	Class.PrimaryOf;
	ForeignKey;
Icons
	icon="icons/MIR/CandidateKey.gif";
}

Index {
Attributes
	Clustered;
	Generate;
	Unique;
Links
	!Class.Associated;
	IndexMember;
	Key;
Icons
	icon="icons/MIR/Index.gif";
}

IndexMember {
Attributes
	Position;
	SortOrder="Sort Order";
Links
	!Index;
	Attribute;
Icons
	icon="icons/MIR/IndexMember.gif";
}

Condition {
Attributes
	Hide;
Links
Icons
	icon="icons/MIR/Condition.gif";
}

Cube {
Attributes
Links
	Filter;
	Join;
	CubeDimensionAssociation;
Icons
	icon="icons/MIR/Cube.gif";
}

CubeDimensionAssociation {
Links
	!Cube;
	Dimension;
	Hierarchy;
	AggregationRule;
Icons
	icon="icons/MIR/CubeDimensionAssociation.gif";
}

AggregationRule {
Attributes
	Rule;
Links
	!Measure;
	CubeDimensionAssociation;
Icons
	icon="icons/MIR/AggregationRule.gif";
}

Dimension {
Attributes
	Hide;
	Type="Dimension Type";
	UserDefined="User Defined";
Links
	Hierarchy;
	<check>Hierarchy.Default;
	Level;
	CubeDimensionAssociation;
	Join;
Icons
	icon="icons/MIR/Dimension.gif";
}

DimensionAttribute {
Attributes
	Hide;
	Sort;
	OriginalName="Original Name";
Links
	LevelAttribute;
	<down>DimensionAttribute.Descriptive;
	<up>DimensionAttribute.DescriptiveOf;
Icons
	icon="icons/MIR/DimensionAttribute.gif";
}

Filter {
Attributes
	Hide;
Links
	Cube;
Icons
	icon="icons/MIR/Filter.gif";
}

Hierarchy {
Attributes
Links
	!Dimension;
	!Dimension.DefaultOf;
	HierarchyLevelAssociation;
	<up>HierarchyLevelAssociation.Top;
	<down>HierarchyLevelAssociation.Bottom;
	CubeDimensionAssociation;
Icons
	icon="icons/MIR/Hierarchy.gif";
}

HierarchyLevelAssociation {
Attributes
	Position;
Links
	!Hierarchy;
	!<up>Hierarchy.TopOf;
	!<down>Hierarchy.BottomOf;
	<forward>Level;
	<forward>LevelAssociation;
Icons
	icon="icons/MIR/HierarchyLevelAssociation.gif";
}

DrillPath {
Attributes
Links
    DrillPathLevelAssociation;
    <up>DrillPathLevelAssociation.Top;
    <down>DrillPathLevelAssociation.Bottom;
Icons
	icon="icons/MIR/DrillPath.gif";
}

DrillPathLevelAssociation {
Attributes
    Position;
Links
    !DrillPath;
    !<up>DrillPath.TopOf;
    !<down>DrillPath.BottomOf;
    <forward>Level;
    <forward>LevelAssociation;
Icons
	icon="icons/MIR/DrillPathLevelAssociation.gif";
}

Join {
Attributes
	Type="Join Type";
	UserDefined="User Defined";
Links
	JoinRole;
	Cube;
	Dimension;
Icons
	icon="icons/MIR/Join.gif";
}

JoinRole {
Attributes
	Left;
	Multiplicity;
Links
	!Join;
	Classifier;
Icons
	icon="icons/MIR/JoinRole.gif";
}

Level {
Attributes
Links
	!Dimension;
	LevelKey;
	LevelAssociation.ParentOf;
	<back>LevelAssociation.ChildOf;
	<back>HierarchyLevelAssociation;
	<back>DrillPathLevelAssociation;
Icons
	icon="icons/MIR/Level.gif";
}

LevelAttribute {
Attributes
Links
	LevelKey;
	DimensionAttribute;
Icons
	icon="icons/MIR/LevelAttribute.gif";
}

LevelKey {
Attributes
Links
	!Level;
	LevelAttribute;
Icons
	icon="icons/MIR/LevelKey.gif";
}

LevelAssociation {
Attributes
Links
    <forward>Level.Child;
    <back>HierarchyLevelAssociation;
    <back>DrillPathLevelAssociation;
    !Level.Parent;
Icons
    icon="icons/MIR/LevelAssociation.gif";
}

Measure {
Attributes
	DefaultAggregation="Default Aggregation";
	Hide;
	Sort;
Links
	AggregationRule;
Icons
	icon="icons/MIR/Measure.gif";
}

PhysicalObject {
Attributes
	ObjectType="Object Type";
Links
	!PhysicalTarget;
	ModelObject;
	<forward>PhysicalRelationship.DestinationOf;
	<back>PhysicalRelationship.SourceOf;
Icons
	icon="icons/MIR/PhysicalObject.gif";
}

PhysicalRelationship {
Attributes
Links
	!<back>PhysicalObject.Source;
	<forward>PhysicalObject.Destination;
Icons
	icon="icons/MIR/PhysicalRelationship.gif";
}

PhysicalTarget {
Attributes
	TargetType="Target Type";
Links
	!Model;
	PhysicalObject;
Icons
	icon="icons/MIR/PhysicalTarget.gif";
}

Diagram {
Attributes
Links
	!DesignPackage;
	!DesignPackage.DefaultOf;
	ModelElement;
	PresentationElement;
Icons
	icon="icons/MIR/Diagram.gif";
}

ClassDiagram {
Attributes
Links
Icons
	icon="icons/MIR/ClassDiagram.gif";
}

PresentationElement {
Attributes
Links
	!Diagram;
	ModelObject.Subject;
Icons
	icon="icons/MIR/PresentationElement.gif";
}

Projection {
Attributes
	BackgroundColor="Background Color";
	LineColor="Line Color";
	FontColor="Font Color";
	FontName="Font Name";
	FontSize="Font Size";
	X;
	Y;
	Width;
	Height;
	Italic;
	Bold;
	Underline;
	Strike;
Links
Icons
	icon="icons/MIR/Projection.gif";
}

RelationshipProjection {
Attributes
	LinePoints="Line Points";
Links
Icons
	icon="icons/MIR/RelationshipProjection.gif";
}

MappingObject {
Attributes
	PhysicalID="Physical ID";
Links
Icons
	icon="icons/MIR/MappingObject.gif";
}

################################################################
# Transformation metadata (inherits from TransformationObject) #
################################################################

MappingModel {
Attributes
	-CreationTime="Creation Time";
Links
	!MappingFormat;
	MetadataOrigin;
	Class.Variable;
	Transformation;
	PropertyElementTypeScope;
	Type;
Icons
	icon="icons/MIR/MappingModel.gif";
}

TransformationActivity {
Attributes
Links
    !DesignPackage;
    TransformationStep;
    StepPrecedence;
Icons
	icon="icons/MIR/TransformationActivity.gif";
}

TransformationStep {
Attributes
Links
    <forward>TransformationTask;
    !TransformationActivity;
    Transformation;
    StepPrecedence.SourceOf;
    StepPrecedence.DestinationOf;
Icons
	icon="icons/MIR/TransformationStep.gif";
}

StepPrecedence {
Attributes
    Operation;
    OperationDescription="Operation Description";
    Type;
Links
    !TransformationActivity;
    <back>TransformationStep.Source;
    <forward>TransformationStep.Destination;
Icons
	icon="icons/MIR/StepPrecedence.gif";
}

TransformationTask {
Attributes
Links
    Transformation;
    <back>TransformationStep;
    !DesignPackage;
Icons
	icon="icons/MIR/TransformationTask.gif";
}

Transformation {
Attributes
	!Operation="Transformation Operation";
	!OperationDescription="Transformation Operation Description";
	NativeType="Native Type";
	!TransformationType="Transformation Type";
	!ElementType;
	!Name;
	!ID;
	!PhysicalID;
	!MappingType;
	!Description;
Links
	ClassifierMap;
	DataSet;
	!MappingModel;
	!TransformationActivity;
	!TransformationStep;
Icons
	icon="icons/MIR/Transformation.gif";
}

ClassifierMap {
Attributes
	Operation="Operation";
	OperationDescription="Operation Description";
	!ElementType;
	!Name;
	!ID;
	!PhysicalID;
	!MappingType;
	!Description;
Links
	!Transformation;
	<external|back>Classifier.Source;
	<external|forward>Classifier.Destination;
	FeatureMap;
	Expression;
Icons
	icon="icons/MIR/ClassifierMap.gif";
}

FeatureMap {
Attributes
	Operation="Operation";
	OperationDescription="Operation Description";
	!ElementType;
	!Name;
	!ID;
	!PhysicalID;
	!MappingType;
	!Description;
	!Position;
Links
	<external|back>Feature.Source;
	<external|forward>Feature.Destination;
	!ClassifierMap;
	Expression;
Icons
	icon="icons/MIR/FeatureMap.gif";
}

DataSet {
Attributes
Links
    !Transformation;
Icons
	icon="icons/MIR/DataSet.gif";
}

DataAttribute {
Attributes
Links
Icons
	icon="icons/MIR/DataAttribute.gif";
}

##################################################
# Mapping metadata (inherits from MappingObject) #
##################################################
ClassMap {
Attributes
	Position;
	WhereClause="Where Clause";
	Distinct;
	CommitType="Commit Type";
	MovementType="Movement Type";
	Volumetrics;
Links
	<external|back>Attribute.Source;
	<external|back>Attribute.Destination;
Icons
	icon="icons/MIR/ClassMap.gif";
}

TypeValueMap {
Attributes
Links
	!ClassifierMap;
	<external|forward>TypeValue.Destination;
	<external|back>TypeValue.Source;
Icons
	icon="icons/MIR/TypeValueMap.gif";
}

EnumeratedTypeMap {
Attributes
Links
	<external|forward>DerivedType.Destination;
	<external|back>DerivedType.Source;
Icons
	icon="icons/MIR/EnumeratedTypeMap.gif";
}

AttributeMap {
Attributes
Links
Icons
	icon="icons/MIR/AttributeMap.gif";
}

KeyMap {
Attributes
Links
	<external|forward>Key.Destination;
	<external|back>ModelObject.Source;
	<up>KeyMap.Parent;
	<down>KeyMap.Child;
Icons
	icon="icons/MIR/KeyMap.gif";
}

EnumeratedAttributeMap {
Attributes
Links
	EnumeratedTypeMap;
Icons
	icon="icons/MIR/EnumeratedAttributeMap.gif";
}

###############################################
# Expression metadata (inherits from Element) #
###############################################

ElementNamePart {
Attributes
    Position;
    SourceElementType="Source Element Type";
Links
    !ElementNode;
    <forward>Element.Referenced;
Icons
	icon="icons/MIR/ElementNamePart.gif";
}

Predicate {
Attributes
    Position;
    Prefix;
Links
    !PredicateNode;
Icons
	icon="icons/MIR/Predicate.gif";
}

Expression {
Attributes
    Status;
Links
	StatementNode;
	!ClassifierMap;
	!FeatureMap;
Icons
	icon="icons/MIR/Expression.gif";
}

ExpressionNode {
Attributes
	Position;
	Block;
	Status;
Links
    <forward>Type;
    <forward>ExpressionNode.Next;
    <back>ExpressionNode.Previous;
    StatementNode.ReferencedBy;
    !BranchingNode;
    !BranchingNode.ConditionOf;
    !DelimiterNode;
    !OperationNode;
    !OperatorNode.LeftOf;
    !OperatorNode.RightOf;
    !PredicateNode;
    !StatementNode;
Icons
	icon="icons/MIR/ExpressionNode.gif";
}

ConstantNode {
Attributes
Links
Icons
	icon="icons/MIR/ConstantNode.gif";
}

ElementNode {
Attributes
    DestinationElementType="Destination Element Type";
    Kind;
Links
	<forward>Element;
	ElementNamePart;
Icons
	icon="icons/MIR/ElementNode.gif";
}

OperationNode {
Attributes
Links
    <forward>Operation;
    ExpressionNode;
Icons
	icon="icons/MIR/OperationNode.gif";
}

ParserNode {
Attributes
Links
Icons
	icon="icons/MIR/ParserNode.gif";
}

BranchingNode {
Attributes
Links
    ExpressionNode.Condition;
    ExpressionNode;
Icons
	icon="icons/MIR/BranchingNode.gif";
}

DelimiterNode {
Attributes
   Delimiter;
Links
    ExpressionNode;
Icons
	icon="icons/MIR/DelimiterNode.gif";
}

OperatorNode {
Attributes
Links
    ExpressionNode.Left;
    ExpressionNode.Right;
Icons
	icon="icons/MIR/OperatorNode.gif";
}

PredicateNode {
Attributes
Links
    Predicate;
    ExpressionNode;
Icons
	icon="icons/MIR/PredicateNode.gif";
}

StatementNode {
Attributes
   StatementType;
Links
	ExpressionNode;
	ExpressionNode.Referenced;
	!Expression;
Icons
	icon="icons/MIR/StatementNode.gif";
}

###############################################
# Report metadata (inherits from ModelObject) #
###############################################

Report {
Attributes
Links
    ReportItem;
    ReportDataSet;
Icons
	icon="icons/MIR/Report.gif";
}

ReportAttribute {
Attributes
Links
    ReportField;
Icons
	icon="icons/MIR/ReportAttribute.gif";
}

ReportDataSet {
Attributes
Links
    !Report;
Icons
	icon="icons/MIR/ReportDataSet.gif";
}

ReportItem {
Attributes
    Position;
Links
    ReportItem.Child;
    !Report;
    !ReportItem.Parent;
Icons
	icon="icons/MIR/ReportItem.gif";
}

ReportChart {
Attributes
Links
Icons
	icon="icons/MIR/ReportChart.gif";
}

ReportField {
Attributes
Links
    <back>ReportAttribute;
Icons
	icon="icons/MIR/ReportField.gif";
}

ReportList {
Attributes
Links
Icons
	icon="icons/MIR/ReportList.gif";
}

ReportMatrix {
Attributes
Links
Icons
	icon="icons/MIR/ReportMatrix.gif";
}

ReportPage {
Attributes
Links
Icons
	icon="icons/MIR/ReportPage.gif";
}

ReportPageBody {
Attributes
Links
Icons
	icon="icons/MIR/ReportPageBody.gif";
}

ReportPageFooter {
Attributes
Links
Icons
	icon="icons/MIR/ReportPageFooter.gif";
}

ReportPageHeader {
Attributes
Links
Icons
	icon="icons/MIR/ReportPageHeader.gif";
}

ReportRectangle {
Attributes
Links
Icons
	icon="icons/MIR/ReportRectangle.gif";
}

ReportTable {
Attributes
Links
Icons
	icon="icons/MIR/ReportTable.gif";
}

ReportText {
Attributes
    Value;
Links
Icons
	icon="icons/MIR/ReportText.gif";
}
