# Standard view
# This file is organized by order of inheritance since some
# child object views can override some properties of their parent
# The more abstract objects are listed first in this file
# The more concrete objects are listed last in this file
# - means read-only property or link
# ! means hidden property or link

%label="Meta Integration (UML, CWM, IDEF1X)"

Object {
Attributes
	-ElementType="Element Type";
	-Name;
	-ID;
Links
}

Note {
Attributes
    Value;
    Position;
Links
    !Element;
}

Element {
Attributes
	Description;
Links
	Note;
	PropertyValue;
	!<back>ElementNode;
	!<back>ElementNamePart.ReferencedBy;
}

MetadataOrigin {
Attributes
	VendorName="Vendor Name";
	ToolName="Tool Name";
	ToolVersion="Tool Version";
	FormatName="Format Name";
	FormatVersion="Format Version";
	BridgeName="Bridge Name";
	BridgeVersion="Bridge Version";
	Encoding;
    Source;
    ResourceType="Resource Type";
Links
	!Model;
	!MappingModel;
}

TypeValue {
Attributes
	Position;
	Value;
Links
	!DerivedType;
	!BusinessRule;
	!<external|forward>TypeValueMap.DestinationOf;
	!<external|back>TypeValueMap.SourceOf;
}

PropertyElementTypeScope {
Attributes
	Scope;
Links
	!Model;
	!MappingModel;
	PropertyType;
}

PropertyValue {
Attributes
	Value;
	Position;
Links
	!Element;
	PropertyType;
}

########################################################
# Repository metadata (Inherits from RepositoryObject) #
########################################################

RepositoryObject {
Attributes
    Description;
	-CreationTime="Creation Time";
	Author;
Links
    !PropertyValue;
}

Directory {
Attributes
Links
	Product;
}

Component {
Attributes
Links
	Component.Referenced;
	Component.ReferencedBy;
}

Product {
Attributes
	ProductType="Product Type";
	State;
Links
	!Directory;
	!Product.Parent;
	Product.Child;
	Version;
	<check>Version.Default;
}

Version {
Attributes
Links
	!Product;
	!Product.DefaultOf;
	<original>Format.Original;
	<check>Format.Default;
	Format;
	<double|back>Version.Predecessor;
	<double|forward>Version.Successor;
}

Format {
Attributes
	FormatType="Format Type";
Links
	!Version;
	!Version.OriginalOf;
	!Version.DefaultOf;
}

FileFormat {
Attributes
	-Location;
Links
}

MetadataFormat {
Attributes
Links
}

ModelFormat {
Attributes
Links
	!Model;
	<back>MappingFormat.SourceOf;
	<forward>MappingFormat.DestinationOf;
}

MappingFormat {
Attributes
Links
	!MappingModel;
	<back>ModelFormat.Source;
	<forward>ModelFormat.Destination;
}

DataMovementFormat {
Attributes
Links
}

##############################################
# Model metadata (inherits from ModelObject) #
##############################################

ModelObject {
Attributes
	-PhysicalID="Physical ID";
	-PhysicalName="Physical Name";
	-Status;
	Comment;
	-DesignLevel="Design Level";
	-Stereotype;
Links
	Synonym;
	<external|back>KeyMap.SourceOf;
	PhysicalObject.Associated;
	BusinessRule.Associated;
	PresentationElement.Presentation=;
	DataPackage;
	DesignPackage.ImportedBy;
}

Synonym {
Attributes
Links
    !ModelObject;
}

BusinessRule {
Attributes
    Type;
    Value;
    LowerBound="Lower Bound";
    UpperBound="Upper Bound";
Links
    TypeValue;
    ModelObject;
    !Model;
}

ModelElement {
Attributes
Links
	!DesignPackage;
	Diagram;
}

Type {
Attributes
Links
	!Model;
	!MappingModel;
	AliasType;
	Argument;
	Feature;
	Operation;
	ExpressionNode;
}

# AliasType displays the Type.AliasOf link first
AliasType {
Attributes
Links
	Type.AliasOf;
	Argument;
	Feature;
	Operation;
}

ClassType {
Attributes
Links
	<forward>Class.Associated=;
	AliasType;
	Argument;
	Feature;
	Operation;
}

ConcreteType {
Attributes
	-DataType="Data Type";
	-Length;
	-Scale;
Links
	DerivedType;
}

BaseType {
Attributes
Links
}

DerivedType {
Attributes
	InitialValue="Initial Value";
	LowerBound="Lower Bound";
	UpperBound="Upper Bound";
	-UserDefined="User Defined";
	-NativeDataType="Native Data Type";
	-UserDataType="User Data Type";
Links
	<back>ConcreteType.DerivedFrom;
	TypeValue;
	<external|forward>EnumeratedTypeMap.DestinationOf;
	<external|back>EnumeratedTypeMap.SourceOf;
	AliasType;
	Argument;
	Feature;
	Operation;
}

PropertyType {
Attributes
	-Usage;
	-Group;
	-Position;
Links
	!PropertyElementTypeScope;
	PropertyValue.Instanciated;
}

Classifier {
Attributes
Links
	<external|forward>ClassifierMap.DestinationOf;
	<external|back>ClassifierMap.SourceOf;
	Feature;
	JoinRole.Associated;
	<back>SQLViewAssociation.SourceOf;
}

Feature {
Attributes
	Position;
Links
	!Classifier;
	<external|forward>FeatureMap.DestinationOf;
	<external|back>FeatureMap.SourceOf;
	Type;
	<back>SQLViewAttribute.SourceOf;
}

StructuralFeature {
Attributes
	InitialValue="Initial Value";
	Optional;
Links
}

Class {
Attributes
	CppClassType="Cpp Class Type";
	CppScope="Cpp Scope";
	CppConcurrency="Cpp Concurrency";
	CppAbstract="Cpp Abstract";
	CppPersistent="Cpp Persistent";
	CppMultiplicity="Cpp Multiplicity";
	CppSpace="Cpp Space";
	DimensionalType;
	DimensionalRole;
Links
	Argument;
	Association;
	<check>CandidateKey.Primary;
	Key;
	Index;
	Operation;
	Grouping;
	<up>Generalization.SubtypeOf;
	<down>Generalization.SupertypeOf;
	AssociationRole;
	<forward>Dependency;
	<back>Dependency.SupplierOf;
	<forward>Realization;
	<back>Realization.SpecificationOf;
	<back>ClassType;
	!MappingModel;
}

Attribute {
Attributes
	CppScope="Cpp Scope";
	CppContainment="Cpp Containement";
	CppStatic="Cpp Static";
	CppDerived="Cpp Derived";
	ExtraConstraint="Constraint";
Links
	!AssociationRole.QualifierOf;
	Key;
	IndexMember;
	<forward>AssociationRoleNameMap.DestinationOf;
	<back>AssociationRoleNameMap.SourceOf;
	Generalization.DiscriminatorOf;
	<external|forward>ClassMap.SourceOf;
	<external|forward>ClassMap.DestinationOf;
	Grouping;
}

ArtificialAttribute {
Attributes
Links
}

SQLViewAssociation {
Attributes
	SQLTableSequence="SQL Table Sequence";
Links
	<back>Classifier.Source;
	<forward>SQLViewEntity.Destination;
}

SQLViewAttribute {
Attributes
	Expression;
Links
	<back>Feature.Source;
}

SQLViewEntity {
Attributes
	SQLTableWhereClause="SQL Table Where Clause";
Links
	Operation;
	<forward>SQLViewAssociation.DestinationOf;
}

AliasClassifier {
Attributes
Links
}

AliasFeature {
Attributes
Links
}

Model {
Attributes
	-CreationTime="Creation Time";
Links
	!ModelFormat;
	MetadataOrigin;
	Type;
	BusinessRule;
	PropertyElementTypeScope;
	PhysicalTarget;
}

Package {
Attributes
Links
    !Package.Parent;
    Package.Child;
}

DesignPackage {
Attributes
	UserDefined="User Defined";
Links
	TransformationActivity;
	TransformationTask;
	Diagram.Default;
	Diagram;
	ModelElement;
	StoredProcedure;
	ModelObject.Imported;
}

DataPackage {
Attributes
    Direction;
Links
    ModelObject;
}
 
DatabaseCatalog {
Attributes
    SystemType="System Type";
    NativeVersion="Native Version";
    MajorVersion="Major Version Number";
    MinorVersion="Minor Version Number";
    TertiaryVersion="Release Version Number";
Links
}

DatabaseSchema {
Attributes
Links
}

Operation {
Attributes
	Position;
	CppScope="Cpp Scope";
	CppConcurrency="Cpp Concurrency";
	CppAbstract="Cpp Abstract";
	CppFriend="Cpp Friend";
	CppStatic="Cpp Static";
	CppVirtual="Cpp Virtual";
	Semantics;
	Precondition;
	Postcondition;
Links
	Type.Return;
	Argument;
	!Class.Associated;
	!SQLViewEntity.Associated;
	!<back>OperationNode;
}

StoredProcedure {
Attributes
Links
	!DesignPackage;
Icons
	icon="icons/MIR/Operation.gif";
}

Trigger {
Attributes
	TriggerType="Trigger Type";
	FireOnInsert="Fire on Insert";
	FireOnUpdate="Fire on Updated";
	FireOnDelete="Fire on Delete";
Links
Icons
	icon="icons/MIR/Operation.gif";
}

Argument {
Attributes
	Position;
	DefaultValue="Default Value";
	Kind;
Links
	!Operation;
	!Class.Parameterized;
	Type;
}

Relationship {
Attributes
Links
}

Realization {
Attributes
Links
	<back>Class.Specification;
	<forward>Class.Realization;
}

Dependency {
Attributes
Links
	<forward>Class.Client;
	<back>Class.Supplier;
}

Generalization {
Attributes
	CppScope="Cpp Scope";
	CppVirtual="Cpp Virtual";
	CppFriend="Cpp Friend";
Links
	<up>Class.Supertype;
	<down>Class.Subtype;
	Attribute.Discriminator;
	ForeignKey;
}

Association {
Attributes
	Aggregation;
	ExtraConstraint="Constraint";
	UserDefined="User Defined";
Links
	Class.Associated=;
	AssociationRole;
}

AssociationRole {
Attributes
	Position;
	Source;
	Multiplicity;
	Navigable;
	Ordered;
	ExtraConstraint="Constraint";
	CppScope="Cpp Scope";
	CppContainment="Cpp Containement";
	CppStatic="Cpp Static";
	CppFriend="Cpp Friend";
Links
	!Association;
	Attribute.Qualifier;
	ForeignKey;
	Class.Associated=;
	Grouping;
}

AssociationRoleNameMap {
Attributes
Links
	!ForeignKey;
	<back>Attribute.Source;
	<forward>Attribute.Destination;
}

Grouping {
Attributes
	Position;
	GroupingType="Grouping Type";
	Multiplicity;
Links
	!Class.Associated;
	!Grouping.Parent;
	Grouping.Child;
	AssociationRole.Leaf;
	Attribute.Leaf;
}

Key {
Attributes
Links
	!Class.Associated;
	Attribute;
	Index;
	<external|forward>KeyMap.DestinationOf;
}

ForeignKey {
Attributes
Links
	AssociationRole;
	Generalization;
	CandidateKey;
	AssociationRoleNameMap;
}

CandidateKey {
Attributes
	UniqueKey="Unique Key";
Links
	Class.PrimaryOf;
	ForeignKey;
}

Index {
Attributes
	Clustered;
	Generate;
	Unique;
Links
	!Class.Associated;
	IndexMember;
	Key;
}

IndexMember {
Attributes
	Position;
	SortOrder="Sort Order";
Links
	!Index;
	Attribute;
}

Condition {
Attributes
	Hide;
Links
}

Cube {
Attributes
Links
	Filter;
	Join;
	CubeDimensionAssociation;
}

CubeDimensionAssociation {
Links
	!Cube;
	Dimension;
	Hierarchy;
	AggregationRule;
}

AggregationRule {
Attributes
	Rule;
Links
	!Measure;
	CubeDimensionAssociation;
}

Dimension {
Attributes
	Hide;
	Type="Dimension Type";
	UserDefined="User Defined";
Links
	Hierarchy;
	<check>Hierarchy.Default;
	Level;
	CubeDimensionAssociation;
	Join;
}

DimensionAttribute {
Attributes
	Hide;
	Sort;
	OriginalName="Original Name";
Links
	LevelAttribute;
	<down>DimensionAttribute.Descriptive;
	<up>DimensionAttribute.DescriptiveOf;
}

Filter {
Attributes
	Hide;
Links
	Cube;
}

Hierarchy {
Attributes
Links
	!Dimension;
	!Dimension.DefaultOf;
	HierarchyLevelAssociation;
	<up>HierarchyLevelAssociation.Top;
	<down>HierarchyLevelAssociation.Bottom;
	CubeDimensionAssociation;
}

HierarchyLevelAssociation {
Attributes
	Position;
Links
	!Hierarchy;
	!<up>Hierarchy.TopOf;
	!<down>Hierarchy.BottomOf;
	<forward>Level;
	<forward>LevelAssociation;
}

DrillPath {
Attributes
Links
    DrillPathLevelAssociation;
    <up>DrillPathLevelAssociation.Top;
    <down>DrillPathLevelAssociation.Bottom;
}

DrillPathLevelAssociation {
Attributes
    Position;
Links
    !DrillPath;
    !<up>DrillPath.TopOf;
    !<down>DrillPath.BottomOf;
    <forward>Level;
    <forward>LevelAssociation;
}

Join {
Attributes
	Type="Join Type";
	UserDefined="User Defined";
Links
	JoinRole;
	Cube;
	Dimension;
}

JoinRole {
Attributes
	Left;
	Multiplicity;
Links
	!Join;
	Classifier;
}

Level {
Attributes
Links
	!Dimension;
	LevelKey;
	LevelAssociation.ParentOf;
	<back>LevelAssociation.ChildOf;
	<back>HierarchyLevelAssociation;
	<back>DrillPathLevelAssociation;
}

LevelAttribute {
Attributes
Links
	LevelKey;
	DimensionAttribute;
}

LevelKey {
Attributes
Links
	!Level;
	LevelAttribute;
}

LevelAssociation {
Attributes
Links
    <forward>Level.Child;
    <back>HierarchyLevelAssociation;
    <back>DrillPathLevelAssociation;
    !Level.Parent;
}

Measure {
Attributes
	DefaultAggregation="Default Aggregation";
	Hide;
	Sort;
Links
	AggregationRule;
}

PhysicalObject {
Attributes
	ObjectType="Object Type";
Links
	!PhysicalTarget;
	ModelObject;
	<forward>PhysicalRelationship.DestinationOf;
	<back>PhysicalRelationship.SourceOf;
}

PhysicalRelationship {
Attributes
Links
	!<back>PhysicalObject.Source;
	<forward>PhysicalObject.Destination;
}

PhysicalTarget {
Attributes
	TargetType="Target Type";
Links
	!Model;
	PhysicalObject;
}

Diagram {
Attributes
Links
	!DesignPackage;
	!DesignPackage.DefaultOf;
	ModelElement;
	PresentationElement;
}

ClassDiagram {
Attributes
Links
}

PresentationElement {
Attributes
Links
	!Diagram;
	ModelObject.Subject;
}

Projection {
Attributes
	BackgroundColor="Background Color";
	LineColor="Line Color";
	FontColor="Font Color";
	FontName="Font Name";
	FontSize="Font Size";
	X;
	Y;
	Width;
	Height;
	Italic;
	Bold;
	Underline;
	Strike;
Links
}

RelationshipProjection {
Attributes
	LinePoints="Line Points";
Links
}

MappingObject {
Attributes
	PhysicalID="Physical ID";
Links
}

################################################################
# Transformation metadata (inherits from TransformationObject) #
################################################################

MappingModel {
Attributes
	-CreationTime="Creation Time";
Links
	!MappingFormat;
	MetadataOrigin;
	Class.Variable;
	Transformation;
	PropertyElementTypeScope;
	Type;
}

TransformationActivity {
Attributes
Links
    !DesignPackage;
    TransformationStep;
    StepPrecedence;
}

TransformationStep {
Attributes
Links
    <forward>TransformationTask;
    !TransformationActivity;
    Transformation;
    StepPrecedence.SourceOf;
    StepPrecedence.DestinationOf;
}

StepPrecedence {
Attributes
    Operation;
    OperationDescription="Operation Description";
    Type;
Links
    !TransformationActivity;
    <back>TransformationStep.Source;
    <forward>TransformationStep.Destination;
}

TransformationTask {
Attributes
Links
    Transformation;
    <back>TransformationStep;
    !DesignPackage;
}

Transformation {
Attributes
	Operation;
	OperationDescription="Operation Description";
	-MappingType="Mapping Type";
	NativeType="Native Type";
	TransformationType="Transformation Type";
Links
	ClassifierMap;
	DataSet;
	!MappingModel;
	!TransformationActivity;
	!TransformationStep;
}

ClassifierMap {
Attributes
    MappingType="Mapping Type";
	Operation;
	OperationDescription="Operation Description";
Links
	!Transformation;
	<external|back>Classifier.Source;
	<external|forward>Classifier.Destination;
	FeatureMap;
	Expression;
}

FeatureMap {
Attributes
	Operation;
	OperationDescription="Operation Description";
	Position;
	MappingType="Mapping Type";
Links
	<external|back>Feature.Source;
	<external|forward>Feature.Destination;
	!ClassifierMap;
	Expression;
}

DataSet {
Attributes
Links
    !Transformation;
}

DataAttribute {
Attributes
Links
}

##################################################
# Mapping metadata (inherits from MappingObject) #
##################################################
ClassMap {
Attributes
	Position;
	WhereClause="Where Clause";
	Distinct;
	CommitType="Commit Type";
	MovementType="Movement Type";
	Volumetrics;
Links
	<external|back>Attribute.Source;
	<external|back>Attribute.Destination;
}

TypeValueMap {
Attributes
Links
	!ClassifierMap;
	<external|forward>TypeValue.Destination;
	<external|back>TypeValue.Source;
}

EnumeratedTypeMap {
Attributes
Links
	<external|forward>DerivedType.Destination;
	<external|back>DerivedType.Source;
}

AttributeMap {
Attributes
Links
}

KeyMap {
Attributes
Links
	<external|forward>Key.Destination;
	<external|back>ModelObject.Source;
	<up>KeyMap.Parent;
	<down>KeyMap.Child;
}

EnumeratedAttributeMap {
Attributes
Links
	EnumeratedTypeMap;
}

###############################################
# Expression metadata (inherits from Element) #
###############################################

ElementNamePart {
Attributes
    Position;
    SourceElementType="Source Element Type";
Links
    !ElementNode;
    <forward>Element.Referenced;
}

Predicate {
Attributes
    Position;
    Prefix;
Links
    !PredicateNode;
}

Expression {
Attributes
    Status;
Links
	StatementNode;
	!ClassifierMap;
	!FeatureMap;
}

ExpressionNode {
Attributes
	Position;
	Block;
	Status;
Links
    <forward>Type;
    <forward>ExpressionNode.Next;
    <back>ExpressionNode.Previous;
    StatementNode.ReferencedBy;
    !BranchingNode;
    !BranchingNode.ConditionOf;
    !DelimiterNode;
    !OperationNode;
    !OperatorNode.LeftOf;
    !OperatorNode.RightOf;
    !PredicateNode;
    !StatementNode;
}

ConstantNode {
Attributes
Links
}

ElementNode {
Attributes
    DestinationElementType="Destination Element Type";
    Kind;
Links
	<forward>Element;
	ElementNamePart;
}

OperationNode {
Attributes
Links
    <forward>Operation;
    ExpressionNode;
}

ParserNode {
Attributes
Links
}

BranchingNode {
Attributes
Links
    ExpressionNode.Condition;
    ExpressionNode;
}

DelimiterNode {
Attributes
   Delimiter;
Links
    ExpressionNode;
}

OperatorNode {
Attributes
Links
    ExpressionNode.Left;
    ExpressionNode.Right;
}

PredicateNode {
Attributes
Links
    Predicate;
    ExpressionNode;
}

StatementNode {
Attributes
   StatementType;
Links
	ExpressionNode;
	ExpressionNode.Referenced;
	!Expression;
}

###############################################
# Report metadata (inherits from ModelObject) #
###############################################

Report {
Attributes
Links
    ReportItem;
    ReportDataSet;
}

ReportAttribute {
Attributes
Links
    ReportField;
}

ReportDataSet {
Attributes
Links
    !Report;
}

ReportItem {
Attributes
    Position;
Links
    ReportItem.Child;
    !Report;
    !ReportItem.Parent;
}

ReportChart {
Attributes
Links
}

ReportField {
Attributes
Links
    <back>ReportAttribute;
}

ReportList {
Attributes
Links
}

ReportMatrix {
Attributes
Links
}

ReportPage {
Attributes
Links
}

ReportPageBody {
Attributes
Links
}

ReportPageFooter {
Attributes
Links
}

ReportPageHeader {
Attributes
Links
}

ReportRectangle {
Attributes
Links
}

ReportTable {
Attributes
Links
}

ReportText {
Attributes
    Value;
Links
}
